# acestream-search
Produces acestream m3u playlist, xml epg or json data. 
You need acestream engine to get it working. If You have no acestream and don't want to install, you can use https://github.com/vstavrinov/acestream-service instead of acestream-search.

## Installation:

```
pip install acestream-search
```

## Usage:

```
acestream_search
```

By default You will get long m3u playlist.
See help for for more options:

```
acestream_search -h
```
